Documentation
¶
Index ¶
- func PkgVersion() (semver.Version, error)
- type Cluster
- type ClusterArgs
- type ClusterArray
- type ClusterArrayInput
- type ClusterArrayOutput
- type ClusterInput
- type ClusterKindConfig
- type ClusterKindConfigArgs
- func (ClusterKindConfigArgs) ElementType() reflect.Type
- func (i ClusterKindConfigArgs) ToClusterKindConfigOutput() ClusterKindConfigOutput
- func (i ClusterKindConfigArgs) ToClusterKindConfigOutputWithContext(ctx context.Context) ClusterKindConfigOutput
- func (i ClusterKindConfigArgs) ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
- func (i ClusterKindConfigArgs) ToClusterKindConfigPtrOutputWithContext(ctx context.Context) ClusterKindConfigPtrOutput
- type ClusterKindConfigInput
- type ClusterKindConfigNetworking
- type ClusterKindConfigNetworkingArgs
- func (ClusterKindConfigNetworkingArgs) ElementType() reflect.Type
- func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingOutput() ClusterKindConfigNetworkingOutput
- func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingOutput
- func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
- func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingPtrOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingPtrOutput
- type ClusterKindConfigNetworkingInput
- type ClusterKindConfigNetworkingOutput
- func (o ClusterKindConfigNetworkingOutput) ApiServerAddress() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingOutput) ApiServerPort() pulumi.IntPtrOutput
- func (o ClusterKindConfigNetworkingOutput) DisableDefaultCni() pulumi.BoolPtrOutput
- func (o ClusterKindConfigNetworkingOutput) DnsSearches() pulumi.StringArrayOutput
- func (ClusterKindConfigNetworkingOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNetworkingOutput) IpFamily() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingOutput) KubeProxyMode() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingOutput) PodSubnet() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingOutput) ServiceSubnet() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingOutput() ClusterKindConfigNetworkingOutput
- func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingOutput
- func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
- func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingPtrOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingPtrOutput
- type ClusterKindConfigNetworkingPtrInput
- type ClusterKindConfigNetworkingPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) ApiServerAddress() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) ApiServerPort() pulumi.IntPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) DisableDefaultCni() pulumi.BoolPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) DnsSearches() pulumi.StringArrayOutput
- func (o ClusterKindConfigNetworkingPtrOutput) Elem() ClusterKindConfigNetworkingOutput
- func (ClusterKindConfigNetworkingPtrOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNetworkingPtrOutput) IpFamily() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) KubeProxyMode() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) PodSubnet() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) ServiceSubnet() pulumi.StringPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
- func (o ClusterKindConfigNetworkingPtrOutput) ToClusterKindConfigNetworkingPtrOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingPtrOutput
- type ClusterKindConfigNode
- type ClusterKindConfigNodeArgs
- type ClusterKindConfigNodeArray
- func (ClusterKindConfigNodeArray) ElementType() reflect.Type
- func (i ClusterKindConfigNodeArray) ToClusterKindConfigNodeArrayOutput() ClusterKindConfigNodeArrayOutput
- func (i ClusterKindConfigNodeArray) ToClusterKindConfigNodeArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeArrayOutput
- type ClusterKindConfigNodeArrayInput
- type ClusterKindConfigNodeArrayOutput
- func (ClusterKindConfigNodeArrayOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNodeArrayOutput) Index(i pulumi.IntInput) ClusterKindConfigNodeOutput
- func (o ClusterKindConfigNodeArrayOutput) ToClusterKindConfigNodeArrayOutput() ClusterKindConfigNodeArrayOutput
- func (o ClusterKindConfigNodeArrayOutput) ToClusterKindConfigNodeArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeArrayOutput
- type ClusterKindConfigNodeExtraMount
- type ClusterKindConfigNodeExtraMountArgs
- func (ClusterKindConfigNodeExtraMountArgs) ElementType() reflect.Type
- func (i ClusterKindConfigNodeExtraMountArgs) ToClusterKindConfigNodeExtraMountOutput() ClusterKindConfigNodeExtraMountOutput
- func (i ClusterKindConfigNodeExtraMountArgs) ToClusterKindConfigNodeExtraMountOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountOutput
- type ClusterKindConfigNodeExtraMountArray
- func (ClusterKindConfigNodeExtraMountArray) ElementType() reflect.Type
- func (i ClusterKindConfigNodeExtraMountArray) ToClusterKindConfigNodeExtraMountArrayOutput() ClusterKindConfigNodeExtraMountArrayOutput
- func (i ClusterKindConfigNodeExtraMountArray) ToClusterKindConfigNodeExtraMountArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountArrayOutput
- type ClusterKindConfigNodeExtraMountArrayInput
- type ClusterKindConfigNodeExtraMountArrayOutput
- func (ClusterKindConfigNodeExtraMountArrayOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNodeExtraMountArrayOutput) Index(i pulumi.IntInput) ClusterKindConfigNodeExtraMountOutput
- func (o ClusterKindConfigNodeExtraMountArrayOutput) ToClusterKindConfigNodeExtraMountArrayOutput() ClusterKindConfigNodeExtraMountArrayOutput
- func (o ClusterKindConfigNodeExtraMountArrayOutput) ToClusterKindConfigNodeExtraMountArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountArrayOutput
- type ClusterKindConfigNodeExtraMountInput
- type ClusterKindConfigNodeExtraMountOutput
- func (o ClusterKindConfigNodeExtraMountOutput) ContainerPath() pulumi.StringPtrOutput
- func (ClusterKindConfigNodeExtraMountOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNodeExtraMountOutput) HostPath() pulumi.StringPtrOutput
- func (o ClusterKindConfigNodeExtraMountOutput) Propagation() pulumi.StringPtrOutput
- func (o ClusterKindConfigNodeExtraMountOutput) ReadOnly() pulumi.BoolPtrOutput
- func (o ClusterKindConfigNodeExtraMountOutput) SelinuxRelabel() pulumi.BoolPtrOutput
- func (o ClusterKindConfigNodeExtraMountOutput) ToClusterKindConfigNodeExtraMountOutput() ClusterKindConfigNodeExtraMountOutput
- func (o ClusterKindConfigNodeExtraMountOutput) ToClusterKindConfigNodeExtraMountOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountOutput
- type ClusterKindConfigNodeExtraPortMapping
- type ClusterKindConfigNodeExtraPortMappingArgs
- func (ClusterKindConfigNodeExtraPortMappingArgs) ElementType() reflect.Type
- func (i ClusterKindConfigNodeExtraPortMappingArgs) ToClusterKindConfigNodeExtraPortMappingOutput() ClusterKindConfigNodeExtraPortMappingOutput
- func (i ClusterKindConfigNodeExtraPortMappingArgs) ToClusterKindConfigNodeExtraPortMappingOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingOutput
- type ClusterKindConfigNodeExtraPortMappingArray
- func (ClusterKindConfigNodeExtraPortMappingArray) ElementType() reflect.Type
- func (i ClusterKindConfigNodeExtraPortMappingArray) ToClusterKindConfigNodeExtraPortMappingArrayOutput() ClusterKindConfigNodeExtraPortMappingArrayOutput
- func (i ClusterKindConfigNodeExtraPortMappingArray) ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingArrayOutput
- type ClusterKindConfigNodeExtraPortMappingArrayInput
- type ClusterKindConfigNodeExtraPortMappingArrayOutput
- func (ClusterKindConfigNodeExtraPortMappingArrayOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNodeExtraPortMappingArrayOutput) Index(i pulumi.IntInput) ClusterKindConfigNodeExtraPortMappingOutput
- func (o ClusterKindConfigNodeExtraPortMappingArrayOutput) ToClusterKindConfigNodeExtraPortMappingArrayOutput() ClusterKindConfigNodeExtraPortMappingArrayOutput
- func (o ClusterKindConfigNodeExtraPortMappingArrayOutput) ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingArrayOutput
- type ClusterKindConfigNodeExtraPortMappingInput
- type ClusterKindConfigNodeExtraPortMappingOutput
- func (o ClusterKindConfigNodeExtraPortMappingOutput) ContainerPort() pulumi.IntPtrOutput
- func (ClusterKindConfigNodeExtraPortMappingOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNodeExtraPortMappingOutput) HostPort() pulumi.IntPtrOutput
- func (o ClusterKindConfigNodeExtraPortMappingOutput) ListenAddress() pulumi.StringPtrOutput
- func (o ClusterKindConfigNodeExtraPortMappingOutput) Protocol() pulumi.StringPtrOutput
- func (o ClusterKindConfigNodeExtraPortMappingOutput) ToClusterKindConfigNodeExtraPortMappingOutput() ClusterKindConfigNodeExtraPortMappingOutput
- func (o ClusterKindConfigNodeExtraPortMappingOutput) ToClusterKindConfigNodeExtraPortMappingOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingOutput
- type ClusterKindConfigNodeInput
- type ClusterKindConfigNodeOutput
- func (ClusterKindConfigNodeOutput) ElementType() reflect.Type
- func (o ClusterKindConfigNodeOutput) ExtraMounts() ClusterKindConfigNodeExtraMountArrayOutput
- func (o ClusterKindConfigNodeOutput) ExtraPortMappings() ClusterKindConfigNodeExtraPortMappingArrayOutput
- func (o ClusterKindConfigNodeOutput) Image() pulumi.StringPtrOutput
- func (o ClusterKindConfigNodeOutput) KubeadmConfigPatches() pulumi.StringArrayOutput
- func (o ClusterKindConfigNodeOutput) Labels() pulumi.StringMapOutput
- func (o ClusterKindConfigNodeOutput) Role() pulumi.StringPtrOutput
- func (o ClusterKindConfigNodeOutput) ToClusterKindConfigNodeOutput() ClusterKindConfigNodeOutput
- func (o ClusterKindConfigNodeOutput) ToClusterKindConfigNodeOutputWithContext(ctx context.Context) ClusterKindConfigNodeOutput
- type ClusterKindConfigOutput
- func (o ClusterKindConfigOutput) ApiVersion() pulumi.StringOutput
- func (o ClusterKindConfigOutput) ContainerdConfigPatches() pulumi.StringArrayOutput
- func (ClusterKindConfigOutput) ElementType() reflect.Type
- func (o ClusterKindConfigOutput) FeatureGates() pulumi.StringMapOutput
- func (o ClusterKindConfigOutput) Kind() pulumi.StringOutput
- func (o ClusterKindConfigOutput) Networking() ClusterKindConfigNetworkingPtrOutput
- func (o ClusterKindConfigOutput) Nodes() ClusterKindConfigNodeArrayOutput
- func (o ClusterKindConfigOutput) RuntimeConfig() pulumi.StringMapOutput
- func (o ClusterKindConfigOutput) ToClusterKindConfigOutput() ClusterKindConfigOutput
- func (o ClusterKindConfigOutput) ToClusterKindConfigOutputWithContext(ctx context.Context) ClusterKindConfigOutput
- func (o ClusterKindConfigOutput) ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
- func (o ClusterKindConfigOutput) ToClusterKindConfigPtrOutputWithContext(ctx context.Context) ClusterKindConfigPtrOutput
- type ClusterKindConfigPtrInput
- type ClusterKindConfigPtrOutput
- func (o ClusterKindConfigPtrOutput) ApiVersion() pulumi.StringPtrOutput
- func (o ClusterKindConfigPtrOutput) ContainerdConfigPatches() pulumi.StringArrayOutput
- func (o ClusterKindConfigPtrOutput) Elem() ClusterKindConfigOutput
- func (ClusterKindConfigPtrOutput) ElementType() reflect.Type
- func (o ClusterKindConfigPtrOutput) FeatureGates() pulumi.StringMapOutput
- func (o ClusterKindConfigPtrOutput) Kind() pulumi.StringPtrOutput
- func (o ClusterKindConfigPtrOutput) Networking() ClusterKindConfigNetworkingPtrOutput
- func (o ClusterKindConfigPtrOutput) Nodes() ClusterKindConfigNodeArrayOutput
- func (o ClusterKindConfigPtrOutput) RuntimeConfig() pulumi.StringMapOutput
- func (o ClusterKindConfigPtrOutput) ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
- func (o ClusterKindConfigPtrOutput) ToClusterKindConfigPtrOutputWithContext(ctx context.Context) ClusterKindConfigPtrOutput
- type ClusterMap
- type ClusterMapInput
- type ClusterMapOutput
- type ClusterOutput
- func (o ClusterOutput) ClientCertificate() pulumi.StringOutput
- func (o ClusterOutput) ClientKey() pulumi.StringOutput
- func (o ClusterOutput) ClusterCaCertificate() pulumi.StringOutput
- func (o ClusterOutput) Completed() pulumi.BoolOutput
- func (ClusterOutput) ElementType() reflect.Type
- func (o ClusterOutput) Endpoint() pulumi.StringOutput
- func (o ClusterOutput) KindConfig() ClusterKindConfigPtrOutput
- func (o ClusterOutput) Kubeconfig() pulumi.StringOutput
- func (o ClusterOutput) KubeconfigPath() pulumi.StringOutput
- func (o ClusterOutput) Name() pulumi.StringOutput
- func (o ClusterOutput) NodeImage() pulumi.StringOutput
- func (o ClusterOutput) ToClusterOutput() ClusterOutput
- func (o ClusterOutput) ToClusterOutputWithContext(ctx context.Context) ClusterOutput
- func (o ClusterOutput) WaitForReady() pulumi.BoolPtrOutput
- type ClusterState
- type Provider
- type ProviderArgs
- type ProviderInput
- type ProviderOutput
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PkgVersion ¶
PkgVersion uses reflection to determine the version of the current package. If a version cannot be determined, v1 will be assumed. The second return value is always nil.
Types ¶
type Cluster ¶
type Cluster struct {
pulumi.CustomResourceState
// Client certificate for authenticating to cluster.
ClientCertificate pulumi.StringOutput `pulumi:"clientCertificate"`
// Client key for authenticating to cluster.
ClientKey pulumi.StringOutput `pulumi:"clientKey"`
// Client verifies the server certificate with this CA cert.
ClusterCaCertificate pulumi.StringOutput `pulumi:"clusterCaCertificate"`
// Cluster successfully created.
Completed pulumi.BoolOutput `pulumi:"completed"`
// Kubernetes APIServer endpoint.
Endpoint pulumi.StringOutput `pulumi:"endpoint"`
// The kindConfig that kind will use.
KindConfig ClusterKindConfigPtrOutput `pulumi:"kindConfig"`
// The kubeconfig for the cluster after it is created
Kubeconfig pulumi.StringOutput `pulumi:"kubeconfig"`
// kubeconfig path set after the the cluster is created or by the user to override defaults.
KubeconfigPath pulumi.StringOutput `pulumi:"kubeconfigPath"`
// The kind name that is given to the created cluster.
Name pulumi.StringOutput `pulumi:"name"`
// The nodeImage that kind will use (ex: kindest/node:v1.27.1).
NodeImage pulumi.StringOutput `pulumi:"nodeImage"`
// Defines wether or not the provider will wait for the control plane to be ready. Defaults to false.
WaitForReady pulumi.BoolPtrOutput `pulumi:"waitForReady"`
}
func GetCluster ¶
func GetCluster(ctx *pulumi.Context, name string, id pulumi.IDInput, state *ClusterState, opts ...pulumi.ResourceOption) (*Cluster, error)
GetCluster gets an existing Cluster resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewCluster ¶
func NewCluster(ctx *pulumi.Context, name string, args *ClusterArgs, opts ...pulumi.ResourceOption) (*Cluster, error)
NewCluster registers a new resource with the given unique name, arguments, and options.
func (*Cluster) ElementType ¶
func (*Cluster) ToClusterOutput ¶
func (i *Cluster) ToClusterOutput() ClusterOutput
func (*Cluster) ToClusterOutputWithContext ¶
func (i *Cluster) ToClusterOutputWithContext(ctx context.Context) ClusterOutput
type ClusterArgs ¶
type ClusterArgs struct {
// The kindConfig that kind will use.
KindConfig ClusterKindConfigPtrInput
// kubeconfig path set after the the cluster is created or by the user to override defaults.
KubeconfigPath pulumi.StringPtrInput
// The kind name that is given to the created cluster.
Name pulumi.StringPtrInput
// The nodeImage that kind will use (ex: kindest/node:v1.27.1).
NodeImage pulumi.StringPtrInput
// Defines wether or not the provider will wait for the control plane to be ready. Defaults to false.
WaitForReady pulumi.BoolPtrInput
}
The set of arguments for constructing a Cluster resource.
func (ClusterArgs) ElementType ¶
func (ClusterArgs) ElementType() reflect.Type
type ClusterArray ¶
type ClusterArray []ClusterInput
func (ClusterArray) ElementType ¶
func (ClusterArray) ElementType() reflect.Type
func (ClusterArray) ToClusterArrayOutput ¶
func (i ClusterArray) ToClusterArrayOutput() ClusterArrayOutput
func (ClusterArray) ToClusterArrayOutputWithContext ¶
func (i ClusterArray) ToClusterArrayOutputWithContext(ctx context.Context) ClusterArrayOutput
type ClusterArrayInput ¶
type ClusterArrayInput interface {
pulumi.Input
ToClusterArrayOutput() ClusterArrayOutput
ToClusterArrayOutputWithContext(context.Context) ClusterArrayOutput
}
ClusterArrayInput is an input type that accepts ClusterArray and ClusterArrayOutput values. You can construct a concrete instance of `ClusterArrayInput` via:
ClusterArray{ ClusterArgs{...} }
type ClusterArrayOutput ¶
type ClusterArrayOutput struct{ *pulumi.OutputState }
func (ClusterArrayOutput) ElementType ¶
func (ClusterArrayOutput) ElementType() reflect.Type
func (ClusterArrayOutput) Index ¶
func (o ClusterArrayOutput) Index(i pulumi.IntInput) ClusterOutput
func (ClusterArrayOutput) ToClusterArrayOutput ¶
func (o ClusterArrayOutput) ToClusterArrayOutput() ClusterArrayOutput
func (ClusterArrayOutput) ToClusterArrayOutputWithContext ¶
func (o ClusterArrayOutput) ToClusterArrayOutputWithContext(ctx context.Context) ClusterArrayOutput
type ClusterInput ¶
type ClusterInput interface {
pulumi.Input
ToClusterOutput() ClusterOutput
ToClusterOutputWithContext(ctx context.Context) ClusterOutput
}
type ClusterKindConfig ¶
type ClusterKindConfig struct {
ApiVersion string `pulumi:"apiVersion"`
ContainerdConfigPatches []string `pulumi:"containerdConfigPatches"`
FeatureGates map[string]string `pulumi:"featureGates"`
Kind string `pulumi:"kind"`
Networking *ClusterKindConfigNetworking `pulumi:"networking"`
Nodes []ClusterKindConfigNode `pulumi:"nodes"`
RuntimeConfig map[string]string `pulumi:"runtimeConfig"`
}
type ClusterKindConfigArgs ¶
type ClusterKindConfigArgs struct {
ApiVersion pulumi.StringInput `pulumi:"apiVersion"`
ContainerdConfigPatches pulumi.StringArrayInput `pulumi:"containerdConfigPatches"`
FeatureGates pulumi.StringMapInput `pulumi:"featureGates"`
Kind pulumi.StringInput `pulumi:"kind"`
Networking ClusterKindConfigNetworkingPtrInput `pulumi:"networking"`
Nodes ClusterKindConfigNodeArrayInput `pulumi:"nodes"`
RuntimeConfig pulumi.StringMapInput `pulumi:"runtimeConfig"`
}
func (ClusterKindConfigArgs) ElementType ¶
func (ClusterKindConfigArgs) ElementType() reflect.Type
func (ClusterKindConfigArgs) ToClusterKindConfigOutput ¶
func (i ClusterKindConfigArgs) ToClusterKindConfigOutput() ClusterKindConfigOutput
func (ClusterKindConfigArgs) ToClusterKindConfigOutputWithContext ¶
func (i ClusterKindConfigArgs) ToClusterKindConfigOutputWithContext(ctx context.Context) ClusterKindConfigOutput
func (ClusterKindConfigArgs) ToClusterKindConfigPtrOutput ¶
func (i ClusterKindConfigArgs) ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
func (ClusterKindConfigArgs) ToClusterKindConfigPtrOutputWithContext ¶
func (i ClusterKindConfigArgs) ToClusterKindConfigPtrOutputWithContext(ctx context.Context) ClusterKindConfigPtrOutput
type ClusterKindConfigInput ¶
type ClusterKindConfigInput interface {
pulumi.Input
ToClusterKindConfigOutput() ClusterKindConfigOutput
ToClusterKindConfigOutputWithContext(context.Context) ClusterKindConfigOutput
}
ClusterKindConfigInput is an input type that accepts ClusterKindConfigArgs and ClusterKindConfigOutput values. You can construct a concrete instance of `ClusterKindConfigInput` via:
ClusterKindConfigArgs{...}
type ClusterKindConfigNetworking ¶
type ClusterKindConfigNetworking struct {
ApiServerAddress *string `pulumi:"apiServerAddress"`
ApiServerPort *int `pulumi:"apiServerPort"`
DisableDefaultCni *bool `pulumi:"disableDefaultCni"`
DnsSearches []string `pulumi:"dnsSearches"`
IpFamily *string `pulumi:"ipFamily"`
KubeProxyMode *string `pulumi:"kubeProxyMode"`
PodSubnet *string `pulumi:"podSubnet"`
ServiceSubnet *string `pulumi:"serviceSubnet"`
}
type ClusterKindConfigNetworkingArgs ¶
type ClusterKindConfigNetworkingArgs struct {
ApiServerAddress pulumi.StringPtrInput `pulumi:"apiServerAddress"`
ApiServerPort pulumi.IntPtrInput `pulumi:"apiServerPort"`
DisableDefaultCni pulumi.BoolPtrInput `pulumi:"disableDefaultCni"`
DnsSearches pulumi.StringArrayInput `pulumi:"dnsSearches"`
IpFamily pulumi.StringPtrInput `pulumi:"ipFamily"`
KubeProxyMode pulumi.StringPtrInput `pulumi:"kubeProxyMode"`
PodSubnet pulumi.StringPtrInput `pulumi:"podSubnet"`
ServiceSubnet pulumi.StringPtrInput `pulumi:"serviceSubnet"`
}
func (ClusterKindConfigNetworkingArgs) ElementType ¶
func (ClusterKindConfigNetworkingArgs) ElementType() reflect.Type
func (ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingOutput ¶
func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingOutput() ClusterKindConfigNetworkingOutput
func (ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingOutputWithContext ¶
func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingOutput
func (ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingPtrOutput ¶
func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
func (ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingPtrOutputWithContext ¶
func (i ClusterKindConfigNetworkingArgs) ToClusterKindConfigNetworkingPtrOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingPtrOutput
type ClusterKindConfigNetworkingInput ¶
type ClusterKindConfigNetworkingInput interface {
pulumi.Input
ToClusterKindConfigNetworkingOutput() ClusterKindConfigNetworkingOutput
ToClusterKindConfigNetworkingOutputWithContext(context.Context) ClusterKindConfigNetworkingOutput
}
ClusterKindConfigNetworkingInput is an input type that accepts ClusterKindConfigNetworkingArgs and ClusterKindConfigNetworkingOutput values. You can construct a concrete instance of `ClusterKindConfigNetworkingInput` via:
ClusterKindConfigNetworkingArgs{...}
type ClusterKindConfigNetworkingOutput ¶
type ClusterKindConfigNetworkingOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNetworkingOutput) ApiServerAddress ¶
func (o ClusterKindConfigNetworkingOutput) ApiServerAddress() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingOutput) ApiServerPort ¶
func (o ClusterKindConfigNetworkingOutput) ApiServerPort() pulumi.IntPtrOutput
func (ClusterKindConfigNetworkingOutput) DisableDefaultCni ¶
func (o ClusterKindConfigNetworkingOutput) DisableDefaultCni() pulumi.BoolPtrOutput
func (ClusterKindConfigNetworkingOutput) DnsSearches ¶
func (o ClusterKindConfigNetworkingOutput) DnsSearches() pulumi.StringArrayOutput
func (ClusterKindConfigNetworkingOutput) ElementType ¶
func (ClusterKindConfigNetworkingOutput) ElementType() reflect.Type
func (ClusterKindConfigNetworkingOutput) IpFamily ¶
func (o ClusterKindConfigNetworkingOutput) IpFamily() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingOutput) KubeProxyMode ¶
func (o ClusterKindConfigNetworkingOutput) KubeProxyMode() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingOutput) PodSubnet ¶
func (o ClusterKindConfigNetworkingOutput) PodSubnet() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingOutput) ServiceSubnet ¶
func (o ClusterKindConfigNetworkingOutput) ServiceSubnet() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingOutput ¶
func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingOutput() ClusterKindConfigNetworkingOutput
func (ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingOutputWithContext ¶
func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingOutput
func (ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingPtrOutput ¶
func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
func (ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingPtrOutputWithContext ¶
func (o ClusterKindConfigNetworkingOutput) ToClusterKindConfigNetworkingPtrOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingPtrOutput
type ClusterKindConfigNetworkingPtrInput ¶
type ClusterKindConfigNetworkingPtrInput interface {
pulumi.Input
ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
ToClusterKindConfigNetworkingPtrOutputWithContext(context.Context) ClusterKindConfigNetworkingPtrOutput
}
ClusterKindConfigNetworkingPtrInput is an input type that accepts ClusterKindConfigNetworkingArgs, ClusterKindConfigNetworkingPtr and ClusterKindConfigNetworkingPtrOutput values. You can construct a concrete instance of `ClusterKindConfigNetworkingPtrInput` via:
ClusterKindConfigNetworkingArgs{...}
or:
nil
func ClusterKindConfigNetworkingPtr ¶
func ClusterKindConfigNetworkingPtr(v *ClusterKindConfigNetworkingArgs) ClusterKindConfigNetworkingPtrInput
type ClusterKindConfigNetworkingPtrOutput ¶
type ClusterKindConfigNetworkingPtrOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNetworkingPtrOutput) ApiServerAddress ¶
func (o ClusterKindConfigNetworkingPtrOutput) ApiServerAddress() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) ApiServerPort ¶
func (o ClusterKindConfigNetworkingPtrOutput) ApiServerPort() pulumi.IntPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) DisableDefaultCni ¶
func (o ClusterKindConfigNetworkingPtrOutput) DisableDefaultCni() pulumi.BoolPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) DnsSearches ¶
func (o ClusterKindConfigNetworkingPtrOutput) DnsSearches() pulumi.StringArrayOutput
func (ClusterKindConfigNetworkingPtrOutput) ElementType ¶
func (ClusterKindConfigNetworkingPtrOutput) ElementType() reflect.Type
func (ClusterKindConfigNetworkingPtrOutput) IpFamily ¶
func (o ClusterKindConfigNetworkingPtrOutput) IpFamily() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) KubeProxyMode ¶
func (o ClusterKindConfigNetworkingPtrOutput) KubeProxyMode() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) PodSubnet ¶
func (o ClusterKindConfigNetworkingPtrOutput) PodSubnet() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) ServiceSubnet ¶
func (o ClusterKindConfigNetworkingPtrOutput) ServiceSubnet() pulumi.StringPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) ToClusterKindConfigNetworkingPtrOutput ¶
func (o ClusterKindConfigNetworkingPtrOutput) ToClusterKindConfigNetworkingPtrOutput() ClusterKindConfigNetworkingPtrOutput
func (ClusterKindConfigNetworkingPtrOutput) ToClusterKindConfigNetworkingPtrOutputWithContext ¶
func (o ClusterKindConfigNetworkingPtrOutput) ToClusterKindConfigNetworkingPtrOutputWithContext(ctx context.Context) ClusterKindConfigNetworkingPtrOutput
type ClusterKindConfigNode ¶
type ClusterKindConfigNode struct {
ExtraMounts []ClusterKindConfigNodeExtraMount `pulumi:"extraMounts"`
ExtraPortMappings []ClusterKindConfigNodeExtraPortMapping `pulumi:"extraPortMappings"`
Image *string `pulumi:"image"`
KubeadmConfigPatches []string `pulumi:"kubeadmConfigPatches"`
Labels map[string]string `pulumi:"labels"`
Role *string `pulumi:"role"`
}
type ClusterKindConfigNodeArgs ¶
type ClusterKindConfigNodeArgs struct {
ExtraMounts ClusterKindConfigNodeExtraMountArrayInput `pulumi:"extraMounts"`
ExtraPortMappings ClusterKindConfigNodeExtraPortMappingArrayInput `pulumi:"extraPortMappings"`
Image pulumi.StringPtrInput `pulumi:"image"`
KubeadmConfigPatches pulumi.StringArrayInput `pulumi:"kubeadmConfigPatches"`
Labels pulumi.StringMapInput `pulumi:"labels"`
Role pulumi.StringPtrInput `pulumi:"role"`
}
func (ClusterKindConfigNodeArgs) ElementType ¶
func (ClusterKindConfigNodeArgs) ElementType() reflect.Type
func (ClusterKindConfigNodeArgs) ToClusterKindConfigNodeOutput ¶
func (i ClusterKindConfigNodeArgs) ToClusterKindConfigNodeOutput() ClusterKindConfigNodeOutput
func (ClusterKindConfigNodeArgs) ToClusterKindConfigNodeOutputWithContext ¶
func (i ClusterKindConfigNodeArgs) ToClusterKindConfigNodeOutputWithContext(ctx context.Context) ClusterKindConfigNodeOutput
type ClusterKindConfigNodeArray ¶
type ClusterKindConfigNodeArray []ClusterKindConfigNodeInput
func (ClusterKindConfigNodeArray) ElementType ¶
func (ClusterKindConfigNodeArray) ElementType() reflect.Type
func (ClusterKindConfigNodeArray) ToClusterKindConfigNodeArrayOutput ¶
func (i ClusterKindConfigNodeArray) ToClusterKindConfigNodeArrayOutput() ClusterKindConfigNodeArrayOutput
func (ClusterKindConfigNodeArray) ToClusterKindConfigNodeArrayOutputWithContext ¶
func (i ClusterKindConfigNodeArray) ToClusterKindConfigNodeArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeArrayOutput
type ClusterKindConfigNodeArrayInput ¶
type ClusterKindConfigNodeArrayInput interface {
pulumi.Input
ToClusterKindConfigNodeArrayOutput() ClusterKindConfigNodeArrayOutput
ToClusterKindConfigNodeArrayOutputWithContext(context.Context) ClusterKindConfigNodeArrayOutput
}
ClusterKindConfigNodeArrayInput is an input type that accepts ClusterKindConfigNodeArray and ClusterKindConfigNodeArrayOutput values. You can construct a concrete instance of `ClusterKindConfigNodeArrayInput` via:
ClusterKindConfigNodeArray{ ClusterKindConfigNodeArgs{...} }
type ClusterKindConfigNodeArrayOutput ¶
type ClusterKindConfigNodeArrayOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNodeArrayOutput) ElementType ¶
func (ClusterKindConfigNodeArrayOutput) ElementType() reflect.Type
func (ClusterKindConfigNodeArrayOutput) Index ¶
func (o ClusterKindConfigNodeArrayOutput) Index(i pulumi.IntInput) ClusterKindConfigNodeOutput
func (ClusterKindConfigNodeArrayOutput) ToClusterKindConfigNodeArrayOutput ¶
func (o ClusterKindConfigNodeArrayOutput) ToClusterKindConfigNodeArrayOutput() ClusterKindConfigNodeArrayOutput
func (ClusterKindConfigNodeArrayOutput) ToClusterKindConfigNodeArrayOutputWithContext ¶
func (o ClusterKindConfigNodeArrayOutput) ToClusterKindConfigNodeArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeArrayOutput
type ClusterKindConfigNodeExtraMountArgs ¶
type ClusterKindConfigNodeExtraMountArgs struct {
ContainerPath pulumi.StringPtrInput `pulumi:"containerPath"`
HostPath pulumi.StringPtrInput `pulumi:"hostPath"`
Propagation pulumi.StringPtrInput `pulumi:"propagation"`
ReadOnly pulumi.BoolPtrInput `pulumi:"readOnly"`
SelinuxRelabel pulumi.BoolPtrInput `pulumi:"selinuxRelabel"`
}
func (ClusterKindConfigNodeExtraMountArgs) ElementType ¶
func (ClusterKindConfigNodeExtraMountArgs) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraMountArgs) ToClusterKindConfigNodeExtraMountOutput ¶
func (i ClusterKindConfigNodeExtraMountArgs) ToClusterKindConfigNodeExtraMountOutput() ClusterKindConfigNodeExtraMountOutput
func (ClusterKindConfigNodeExtraMountArgs) ToClusterKindConfigNodeExtraMountOutputWithContext ¶
func (i ClusterKindConfigNodeExtraMountArgs) ToClusterKindConfigNodeExtraMountOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountOutput
type ClusterKindConfigNodeExtraMountArray ¶
type ClusterKindConfigNodeExtraMountArray []ClusterKindConfigNodeExtraMountInput
func (ClusterKindConfigNodeExtraMountArray) ElementType ¶
func (ClusterKindConfigNodeExtraMountArray) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraMountArray) ToClusterKindConfigNodeExtraMountArrayOutput ¶
func (i ClusterKindConfigNodeExtraMountArray) ToClusterKindConfigNodeExtraMountArrayOutput() ClusterKindConfigNodeExtraMountArrayOutput
func (ClusterKindConfigNodeExtraMountArray) ToClusterKindConfigNodeExtraMountArrayOutputWithContext ¶
func (i ClusterKindConfigNodeExtraMountArray) ToClusterKindConfigNodeExtraMountArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountArrayOutput
type ClusterKindConfigNodeExtraMountArrayInput ¶
type ClusterKindConfigNodeExtraMountArrayInput interface {
pulumi.Input
ToClusterKindConfigNodeExtraMountArrayOutput() ClusterKindConfigNodeExtraMountArrayOutput
ToClusterKindConfigNodeExtraMountArrayOutputWithContext(context.Context) ClusterKindConfigNodeExtraMountArrayOutput
}
ClusterKindConfigNodeExtraMountArrayInput is an input type that accepts ClusterKindConfigNodeExtraMountArray and ClusterKindConfigNodeExtraMountArrayOutput values. You can construct a concrete instance of `ClusterKindConfigNodeExtraMountArrayInput` via:
ClusterKindConfigNodeExtraMountArray{ ClusterKindConfigNodeExtraMountArgs{...} }
type ClusterKindConfigNodeExtraMountArrayOutput ¶
type ClusterKindConfigNodeExtraMountArrayOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNodeExtraMountArrayOutput) ElementType ¶
func (ClusterKindConfigNodeExtraMountArrayOutput) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraMountArrayOutput) ToClusterKindConfigNodeExtraMountArrayOutput ¶
func (o ClusterKindConfigNodeExtraMountArrayOutput) ToClusterKindConfigNodeExtraMountArrayOutput() ClusterKindConfigNodeExtraMountArrayOutput
func (ClusterKindConfigNodeExtraMountArrayOutput) ToClusterKindConfigNodeExtraMountArrayOutputWithContext ¶
func (o ClusterKindConfigNodeExtraMountArrayOutput) ToClusterKindConfigNodeExtraMountArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountArrayOutput
type ClusterKindConfigNodeExtraMountInput ¶
type ClusterKindConfigNodeExtraMountInput interface {
pulumi.Input
ToClusterKindConfigNodeExtraMountOutput() ClusterKindConfigNodeExtraMountOutput
ToClusterKindConfigNodeExtraMountOutputWithContext(context.Context) ClusterKindConfigNodeExtraMountOutput
}
ClusterKindConfigNodeExtraMountInput is an input type that accepts ClusterKindConfigNodeExtraMountArgs and ClusterKindConfigNodeExtraMountOutput values. You can construct a concrete instance of `ClusterKindConfigNodeExtraMountInput` via:
ClusterKindConfigNodeExtraMountArgs{...}
type ClusterKindConfigNodeExtraMountOutput ¶
type ClusterKindConfigNodeExtraMountOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNodeExtraMountOutput) ContainerPath ¶
func (o ClusterKindConfigNodeExtraMountOutput) ContainerPath() pulumi.StringPtrOutput
func (ClusterKindConfigNodeExtraMountOutput) ElementType ¶
func (ClusterKindConfigNodeExtraMountOutput) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraMountOutput) HostPath ¶
func (o ClusterKindConfigNodeExtraMountOutput) HostPath() pulumi.StringPtrOutput
func (ClusterKindConfigNodeExtraMountOutput) Propagation ¶
func (o ClusterKindConfigNodeExtraMountOutput) Propagation() pulumi.StringPtrOutput
func (ClusterKindConfigNodeExtraMountOutput) ReadOnly ¶
func (o ClusterKindConfigNodeExtraMountOutput) ReadOnly() pulumi.BoolPtrOutput
func (ClusterKindConfigNodeExtraMountOutput) SelinuxRelabel ¶
func (o ClusterKindConfigNodeExtraMountOutput) SelinuxRelabel() pulumi.BoolPtrOutput
func (ClusterKindConfigNodeExtraMountOutput) ToClusterKindConfigNodeExtraMountOutput ¶
func (o ClusterKindConfigNodeExtraMountOutput) ToClusterKindConfigNodeExtraMountOutput() ClusterKindConfigNodeExtraMountOutput
func (ClusterKindConfigNodeExtraMountOutput) ToClusterKindConfigNodeExtraMountOutputWithContext ¶
func (o ClusterKindConfigNodeExtraMountOutput) ToClusterKindConfigNodeExtraMountOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraMountOutput
type ClusterKindConfigNodeExtraPortMappingArgs ¶
type ClusterKindConfigNodeExtraPortMappingArgs struct {
ContainerPort pulumi.IntPtrInput `pulumi:"containerPort"`
HostPort pulumi.IntPtrInput `pulumi:"hostPort"`
ListenAddress pulumi.StringPtrInput `pulumi:"listenAddress"`
Protocol pulumi.StringPtrInput `pulumi:"protocol"`
}
func (ClusterKindConfigNodeExtraPortMappingArgs) ElementType ¶
func (ClusterKindConfigNodeExtraPortMappingArgs) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraPortMappingArgs) ToClusterKindConfigNodeExtraPortMappingOutput ¶
func (i ClusterKindConfigNodeExtraPortMappingArgs) ToClusterKindConfigNodeExtraPortMappingOutput() ClusterKindConfigNodeExtraPortMappingOutput
func (ClusterKindConfigNodeExtraPortMappingArgs) ToClusterKindConfigNodeExtraPortMappingOutputWithContext ¶
func (i ClusterKindConfigNodeExtraPortMappingArgs) ToClusterKindConfigNodeExtraPortMappingOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingOutput
type ClusterKindConfigNodeExtraPortMappingArray ¶
type ClusterKindConfigNodeExtraPortMappingArray []ClusterKindConfigNodeExtraPortMappingInput
func (ClusterKindConfigNodeExtraPortMappingArray) ElementType ¶
func (ClusterKindConfigNodeExtraPortMappingArray) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraPortMappingArray) ToClusterKindConfigNodeExtraPortMappingArrayOutput ¶
func (i ClusterKindConfigNodeExtraPortMappingArray) ToClusterKindConfigNodeExtraPortMappingArrayOutput() ClusterKindConfigNodeExtraPortMappingArrayOutput
func (ClusterKindConfigNodeExtraPortMappingArray) ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext ¶
func (i ClusterKindConfigNodeExtraPortMappingArray) ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingArrayOutput
type ClusterKindConfigNodeExtraPortMappingArrayInput ¶
type ClusterKindConfigNodeExtraPortMappingArrayInput interface {
pulumi.Input
ToClusterKindConfigNodeExtraPortMappingArrayOutput() ClusterKindConfigNodeExtraPortMappingArrayOutput
ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext(context.Context) ClusterKindConfigNodeExtraPortMappingArrayOutput
}
ClusterKindConfigNodeExtraPortMappingArrayInput is an input type that accepts ClusterKindConfigNodeExtraPortMappingArray and ClusterKindConfigNodeExtraPortMappingArrayOutput values. You can construct a concrete instance of `ClusterKindConfigNodeExtraPortMappingArrayInput` via:
ClusterKindConfigNodeExtraPortMappingArray{ ClusterKindConfigNodeExtraPortMappingArgs{...} }
type ClusterKindConfigNodeExtraPortMappingArrayOutput ¶
type ClusterKindConfigNodeExtraPortMappingArrayOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNodeExtraPortMappingArrayOutput) ElementType ¶
func (ClusterKindConfigNodeExtraPortMappingArrayOutput) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraPortMappingArrayOutput) ToClusterKindConfigNodeExtraPortMappingArrayOutput ¶
func (o ClusterKindConfigNodeExtraPortMappingArrayOutput) ToClusterKindConfigNodeExtraPortMappingArrayOutput() ClusterKindConfigNodeExtraPortMappingArrayOutput
func (ClusterKindConfigNodeExtraPortMappingArrayOutput) ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext ¶
func (o ClusterKindConfigNodeExtraPortMappingArrayOutput) ToClusterKindConfigNodeExtraPortMappingArrayOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingArrayOutput
type ClusterKindConfigNodeExtraPortMappingInput ¶
type ClusterKindConfigNodeExtraPortMappingInput interface {
pulumi.Input
ToClusterKindConfigNodeExtraPortMappingOutput() ClusterKindConfigNodeExtraPortMappingOutput
ToClusterKindConfigNodeExtraPortMappingOutputWithContext(context.Context) ClusterKindConfigNodeExtraPortMappingOutput
}
ClusterKindConfigNodeExtraPortMappingInput is an input type that accepts ClusterKindConfigNodeExtraPortMappingArgs and ClusterKindConfigNodeExtraPortMappingOutput values. You can construct a concrete instance of `ClusterKindConfigNodeExtraPortMappingInput` via:
ClusterKindConfigNodeExtraPortMappingArgs{...}
type ClusterKindConfigNodeExtraPortMappingOutput ¶
type ClusterKindConfigNodeExtraPortMappingOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNodeExtraPortMappingOutput) ContainerPort ¶
func (o ClusterKindConfigNodeExtraPortMappingOutput) ContainerPort() pulumi.IntPtrOutput
func (ClusterKindConfigNodeExtraPortMappingOutput) ElementType ¶
func (ClusterKindConfigNodeExtraPortMappingOutput) ElementType() reflect.Type
func (ClusterKindConfigNodeExtraPortMappingOutput) HostPort ¶
func (o ClusterKindConfigNodeExtraPortMappingOutput) HostPort() pulumi.IntPtrOutput
func (ClusterKindConfigNodeExtraPortMappingOutput) ListenAddress ¶
func (o ClusterKindConfigNodeExtraPortMappingOutput) ListenAddress() pulumi.StringPtrOutput
func (ClusterKindConfigNodeExtraPortMappingOutput) Protocol ¶
func (o ClusterKindConfigNodeExtraPortMappingOutput) Protocol() pulumi.StringPtrOutput
func (ClusterKindConfigNodeExtraPortMappingOutput) ToClusterKindConfigNodeExtraPortMappingOutput ¶
func (o ClusterKindConfigNodeExtraPortMappingOutput) ToClusterKindConfigNodeExtraPortMappingOutput() ClusterKindConfigNodeExtraPortMappingOutput
func (ClusterKindConfigNodeExtraPortMappingOutput) ToClusterKindConfigNodeExtraPortMappingOutputWithContext ¶
func (o ClusterKindConfigNodeExtraPortMappingOutput) ToClusterKindConfigNodeExtraPortMappingOutputWithContext(ctx context.Context) ClusterKindConfigNodeExtraPortMappingOutput
type ClusterKindConfigNodeInput ¶
type ClusterKindConfigNodeInput interface {
pulumi.Input
ToClusterKindConfigNodeOutput() ClusterKindConfigNodeOutput
ToClusterKindConfigNodeOutputWithContext(context.Context) ClusterKindConfigNodeOutput
}
ClusterKindConfigNodeInput is an input type that accepts ClusterKindConfigNodeArgs and ClusterKindConfigNodeOutput values. You can construct a concrete instance of `ClusterKindConfigNodeInput` via:
ClusterKindConfigNodeArgs{...}
type ClusterKindConfigNodeOutput ¶
type ClusterKindConfigNodeOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigNodeOutput) ElementType ¶
func (ClusterKindConfigNodeOutput) ElementType() reflect.Type
func (ClusterKindConfigNodeOutput) ExtraMounts ¶
func (o ClusterKindConfigNodeOutput) ExtraMounts() ClusterKindConfigNodeExtraMountArrayOutput
func (ClusterKindConfigNodeOutput) ExtraPortMappings ¶
func (o ClusterKindConfigNodeOutput) ExtraPortMappings() ClusterKindConfigNodeExtraPortMappingArrayOutput
func (ClusterKindConfigNodeOutput) Image ¶
func (o ClusterKindConfigNodeOutput) Image() pulumi.StringPtrOutput
func (ClusterKindConfigNodeOutput) KubeadmConfigPatches ¶
func (o ClusterKindConfigNodeOutput) KubeadmConfigPatches() pulumi.StringArrayOutput
func (ClusterKindConfigNodeOutput) Labels ¶
func (o ClusterKindConfigNodeOutput) Labels() pulumi.StringMapOutput
func (ClusterKindConfigNodeOutput) Role ¶
func (o ClusterKindConfigNodeOutput) Role() pulumi.StringPtrOutput
func (ClusterKindConfigNodeOutput) ToClusterKindConfigNodeOutput ¶
func (o ClusterKindConfigNodeOutput) ToClusterKindConfigNodeOutput() ClusterKindConfigNodeOutput
func (ClusterKindConfigNodeOutput) ToClusterKindConfigNodeOutputWithContext ¶
func (o ClusterKindConfigNodeOutput) ToClusterKindConfigNodeOutputWithContext(ctx context.Context) ClusterKindConfigNodeOutput
type ClusterKindConfigOutput ¶
type ClusterKindConfigOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigOutput) ApiVersion ¶
func (o ClusterKindConfigOutput) ApiVersion() pulumi.StringOutput
func (ClusterKindConfigOutput) ContainerdConfigPatches ¶
func (o ClusterKindConfigOutput) ContainerdConfigPatches() pulumi.StringArrayOutput
func (ClusterKindConfigOutput) ElementType ¶
func (ClusterKindConfigOutput) ElementType() reflect.Type
func (ClusterKindConfigOutput) FeatureGates ¶
func (o ClusterKindConfigOutput) FeatureGates() pulumi.StringMapOutput
func (ClusterKindConfigOutput) Kind ¶
func (o ClusterKindConfigOutput) Kind() pulumi.StringOutput
func (ClusterKindConfigOutput) Networking ¶
func (o ClusterKindConfigOutput) Networking() ClusterKindConfigNetworkingPtrOutput
func (ClusterKindConfigOutput) Nodes ¶
func (o ClusterKindConfigOutput) Nodes() ClusterKindConfigNodeArrayOutput
func (ClusterKindConfigOutput) RuntimeConfig ¶
func (o ClusterKindConfigOutput) RuntimeConfig() pulumi.StringMapOutput
func (ClusterKindConfigOutput) ToClusterKindConfigOutput ¶
func (o ClusterKindConfigOutput) ToClusterKindConfigOutput() ClusterKindConfigOutput
func (ClusterKindConfigOutput) ToClusterKindConfigOutputWithContext ¶
func (o ClusterKindConfigOutput) ToClusterKindConfigOutputWithContext(ctx context.Context) ClusterKindConfigOutput
func (ClusterKindConfigOutput) ToClusterKindConfigPtrOutput ¶
func (o ClusterKindConfigOutput) ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
func (ClusterKindConfigOutput) ToClusterKindConfigPtrOutputWithContext ¶
func (o ClusterKindConfigOutput) ToClusterKindConfigPtrOutputWithContext(ctx context.Context) ClusterKindConfigPtrOutput
type ClusterKindConfigPtrInput ¶
type ClusterKindConfigPtrInput interface {
pulumi.Input
ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
ToClusterKindConfigPtrOutputWithContext(context.Context) ClusterKindConfigPtrOutput
}
ClusterKindConfigPtrInput is an input type that accepts ClusterKindConfigArgs, ClusterKindConfigPtr and ClusterKindConfigPtrOutput values. You can construct a concrete instance of `ClusterKindConfigPtrInput` via:
ClusterKindConfigArgs{...}
or:
nil
func ClusterKindConfigPtr ¶
func ClusterKindConfigPtr(v *ClusterKindConfigArgs) ClusterKindConfigPtrInput
type ClusterKindConfigPtrOutput ¶
type ClusterKindConfigPtrOutput struct{ *pulumi.OutputState }
func (ClusterKindConfigPtrOutput) ApiVersion ¶
func (o ClusterKindConfigPtrOutput) ApiVersion() pulumi.StringPtrOutput
func (ClusterKindConfigPtrOutput) ContainerdConfigPatches ¶
func (o ClusterKindConfigPtrOutput) ContainerdConfigPatches() pulumi.StringArrayOutput
func (ClusterKindConfigPtrOutput) Elem ¶
func (o ClusterKindConfigPtrOutput) Elem() ClusterKindConfigOutput
func (ClusterKindConfigPtrOutput) ElementType ¶
func (ClusterKindConfigPtrOutput) ElementType() reflect.Type
func (ClusterKindConfigPtrOutput) FeatureGates ¶
func (o ClusterKindConfigPtrOutput) FeatureGates() pulumi.StringMapOutput
func (ClusterKindConfigPtrOutput) Kind ¶
func (o ClusterKindConfigPtrOutput) Kind() pulumi.StringPtrOutput
func (ClusterKindConfigPtrOutput) Networking ¶
func (o ClusterKindConfigPtrOutput) Networking() ClusterKindConfigNetworkingPtrOutput
func (ClusterKindConfigPtrOutput) Nodes ¶
func (o ClusterKindConfigPtrOutput) Nodes() ClusterKindConfigNodeArrayOutput
func (ClusterKindConfigPtrOutput) RuntimeConfig ¶
func (o ClusterKindConfigPtrOutput) RuntimeConfig() pulumi.StringMapOutput
func (ClusterKindConfigPtrOutput) ToClusterKindConfigPtrOutput ¶
func (o ClusterKindConfigPtrOutput) ToClusterKindConfigPtrOutput() ClusterKindConfigPtrOutput
func (ClusterKindConfigPtrOutput) ToClusterKindConfigPtrOutputWithContext ¶
func (o ClusterKindConfigPtrOutput) ToClusterKindConfigPtrOutputWithContext(ctx context.Context) ClusterKindConfigPtrOutput
type ClusterMap ¶
type ClusterMap map[string]ClusterInput
func (ClusterMap) ElementType ¶
func (ClusterMap) ElementType() reflect.Type
func (ClusterMap) ToClusterMapOutput ¶
func (i ClusterMap) ToClusterMapOutput() ClusterMapOutput
func (ClusterMap) ToClusterMapOutputWithContext ¶
func (i ClusterMap) ToClusterMapOutputWithContext(ctx context.Context) ClusterMapOutput
type ClusterMapInput ¶
type ClusterMapInput interface {
pulumi.Input
ToClusterMapOutput() ClusterMapOutput
ToClusterMapOutputWithContext(context.Context) ClusterMapOutput
}
ClusterMapInput is an input type that accepts ClusterMap and ClusterMapOutput values. You can construct a concrete instance of `ClusterMapInput` via:
ClusterMap{ "key": ClusterArgs{...} }
type ClusterMapOutput ¶
type ClusterMapOutput struct{ *pulumi.OutputState }
func (ClusterMapOutput) ElementType ¶
func (ClusterMapOutput) ElementType() reflect.Type
func (ClusterMapOutput) MapIndex ¶
func (o ClusterMapOutput) MapIndex(k pulumi.StringInput) ClusterOutput
func (ClusterMapOutput) ToClusterMapOutput ¶
func (o ClusterMapOutput) ToClusterMapOutput() ClusterMapOutput
func (ClusterMapOutput) ToClusterMapOutputWithContext ¶
func (o ClusterMapOutput) ToClusterMapOutputWithContext(ctx context.Context) ClusterMapOutput
type ClusterOutput ¶
type ClusterOutput struct{ *pulumi.OutputState }
func (ClusterOutput) ClientCertificate ¶
func (o ClusterOutput) ClientCertificate() pulumi.StringOutput
Client certificate for authenticating to cluster.
func (ClusterOutput) ClientKey ¶
func (o ClusterOutput) ClientKey() pulumi.StringOutput
Client key for authenticating to cluster.
func (ClusterOutput) ClusterCaCertificate ¶
func (o ClusterOutput) ClusterCaCertificate() pulumi.StringOutput
Client verifies the server certificate with this CA cert.
func (ClusterOutput) Completed ¶
func (o ClusterOutput) Completed() pulumi.BoolOutput
Cluster successfully created.
func (ClusterOutput) ElementType ¶
func (ClusterOutput) ElementType() reflect.Type
func (ClusterOutput) Endpoint ¶
func (o ClusterOutput) Endpoint() pulumi.StringOutput
Kubernetes APIServer endpoint.
func (ClusterOutput) KindConfig ¶
func (o ClusterOutput) KindConfig() ClusterKindConfigPtrOutput
The kindConfig that kind will use.
func (ClusterOutput) Kubeconfig ¶
func (o ClusterOutput) Kubeconfig() pulumi.StringOutput
The kubeconfig for the cluster after it is created
func (ClusterOutput) KubeconfigPath ¶
func (o ClusterOutput) KubeconfigPath() pulumi.StringOutput
kubeconfig path set after the the cluster is created or by the user to override defaults.
func (ClusterOutput) Name ¶
func (o ClusterOutput) Name() pulumi.StringOutput
The kind name that is given to the created cluster.
func (ClusterOutput) NodeImage ¶
func (o ClusterOutput) NodeImage() pulumi.StringOutput
The nodeImage that kind will use (ex: kindest/node:v1.27.1).
func (ClusterOutput) ToClusterOutput ¶
func (o ClusterOutput) ToClusterOutput() ClusterOutput
func (ClusterOutput) ToClusterOutputWithContext ¶
func (o ClusterOutput) ToClusterOutputWithContext(ctx context.Context) ClusterOutput
func (ClusterOutput) WaitForReady ¶
func (o ClusterOutput) WaitForReady() pulumi.BoolPtrOutput
Defines wether or not the provider will wait for the control plane to be ready. Defaults to false.
type ClusterState ¶
type ClusterState struct {
// Client certificate for authenticating to cluster.
ClientCertificate pulumi.StringPtrInput
// Client key for authenticating to cluster.
ClientKey pulumi.StringPtrInput
// Client verifies the server certificate with this CA cert.
ClusterCaCertificate pulumi.StringPtrInput
// Cluster successfully created.
Completed pulumi.BoolPtrInput
// Kubernetes APIServer endpoint.
Endpoint pulumi.StringPtrInput
// The kindConfig that kind will use.
KindConfig ClusterKindConfigPtrInput
// The kubeconfig for the cluster after it is created
Kubeconfig pulumi.StringPtrInput
// kubeconfig path set after the the cluster is created or by the user to override defaults.
KubeconfigPath pulumi.StringPtrInput
// The kind name that is given to the created cluster.
Name pulumi.StringPtrInput
// The nodeImage that kind will use (ex: kindest/node:v1.27.1).
NodeImage pulumi.StringPtrInput
// Defines wether or not the provider will wait for the control plane to be ready. Defaults to false.
WaitForReady pulumi.BoolPtrInput
}
func (ClusterState) ElementType ¶
func (ClusterState) ElementType() reflect.Type
type Provider ¶
type Provider struct {
pulumi.ProviderResourceState
}
The provider type for the kind package. By default, resources use package-wide configuration settings, however an explicit `Provider` instance may be created and passed during resource construction to achieve fine-grained programmatic control over provider settings. See the [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.
func NewProvider ¶
func NewProvider(ctx *pulumi.Context, name string, args *ProviderArgs, opts ...pulumi.ResourceOption) (*Provider, error)
NewProvider registers a new resource with the given unique name, arguments, and options.
func (*Provider) ElementType ¶
func (*Provider) ToProviderOutput ¶
func (i *Provider) ToProviderOutput() ProviderOutput
func (*Provider) ToProviderOutputWithContext ¶
func (i *Provider) ToProviderOutputWithContext(ctx context.Context) ProviderOutput
type ProviderArgs ¶
type ProviderArgs struct {
}
The set of arguments for constructing a Provider resource.
func (ProviderArgs) ElementType ¶
func (ProviderArgs) ElementType() reflect.Type
type ProviderInput ¶
type ProviderInput interface {
pulumi.Input
ToProviderOutput() ProviderOutput
ToProviderOutputWithContext(ctx context.Context) ProviderOutput
}
type ProviderOutput ¶
type ProviderOutput struct{ *pulumi.OutputState }
func (ProviderOutput) ElementType ¶
func (ProviderOutput) ElementType() reflect.Type
func (ProviderOutput) ToProviderOutput ¶
func (o ProviderOutput) ToProviderOutput() ProviderOutput
func (ProviderOutput) ToProviderOutputWithContext ¶
func (o ProviderOutput) ToProviderOutputWithContext(ctx context.Context) ProviderOutput